<?php
/**
 * Adelle functions and definitions
 *
 * @package Adelle
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) )
	$content_width = 640; /* pixels */

function adelle_set_content_width() {
	global $content_width;
	if ( is_page_template( 'page-full-width.php' ) || is_attachment() )
		$content_width = 1040;
}
add_action( 'template_redirect', 'adelle_set_content_width' );

/*
 * Load Jetpack compatibility file.
 */
require( get_template_directory() . '/inc/jetpack.php' );

if ( ! function_exists( 'adelle_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
function adelle_setup() {

	/**
	 * Make theme available for translation
	 * Translations can be filed in the /languages/ directory
	 * If you're building a theme based on Adelle, use a find and replace
	 * to change 'adelle' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'adelle', get_template_directory() . '/languages' );

	/**
	 * Add default posts and comments RSS feed links to head
	 */
	add_theme_support( 'automatic-feed-links' );

	/**
	 * Enable support for Post Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );

	/**
	 * This theme uses wp_nav_menu() in one location.
	 */
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'adelle' ),
	) );

	/**
	 * Enable support for Post Formats
	 */
	add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link', 'status', 'chat', 'gallery', 'audio' ) );

	/**
	 * Enable support for custom backgrounds
	 */
	add_theme_support( 'custom-background', array(
		'default-color' => 'ffffff',
	) );

}
endif; // adelle_setup
add_action( 'after_setup_theme', 'adelle_setup' );

/**
 * Enqueue Google Fonts
 */

function adelle_fonts() {

	/*	translators: If there are characters in your language that are not supported
		by Muli, translate this to 'off'. Do not translate into your own language. */

	if ( 'off' !== _x( 'on', 'Muli font: on or off', 'adelle' ) ) {

		$protocol = is_ssl() ? 'https' : 'http';

		wp_register_style( 'adelle-muli', "$protocol://fonts.googleapis.com/css?family=Muli:400,400italic" );
	}

	/*	translators: If there are characters in your language that are not supported
		by Montserrat, translate this to 'off'. Do not translate into your own language. */

	if ( 'off' !== _x( 'on', 'Montserrat font: on or off', 'adelle' ) ) {

		$protocol = is_ssl() ? 'https' : 'http';

		wp_register_style( 'adelle-montserrat', "$protocol://fonts.googleapis.com/css?family=Montserrat:400,700" );
	}

	/*	translators: If there are characters in your language that are not supported
		by Lora, translate this to 'off'. Do not translate into your own language. */

	if ( 'off' !== _x( 'on', 'Lora font: on or off', 'adelle' ) ) {

		$protocol = is_ssl() ? 'https' : 'http';

		wp_register_style( 'adelle-lora', "$protocol://fonts.googleapis.com/css?family=Lora:400,400italic,700,700italic" );
	}
}
add_action( 'init', 'adelle_fonts' );

/**
 * Enqueue font styles in custom header admin
 */

function adelle_admin_fonts( $hook_suffix ) {

	if ( 'appearance_page_custom-header' != $hook_suffix )
		return;

	wp_enqueue_style( 'adelle-muli' );
	wp_enqueue_style( 'adelle-montserrat' );
	wp_enqueue_style( 'adelle-lora' );
}
add_action( 'admin_enqueue_scripts', 'adelle_admin_fonts' );

/**
 * Register widgetized area and update sidebar with default widgets
 */
function adelle_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'adelle' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
}
add_action( 'widgets_init', 'adelle_widgets_init' );

/**
 * Enqueue scripts and styles
 */
function adelle_scripts() {
	wp_enqueue_style( 'adelle-style', get_stylesheet_uri() );

	wp_enqueue_style( 'adelle-muli' );

	wp_enqueue_style( 'adelle-lora' );

	wp_enqueue_style( 'adelle-montserrat' );

	wp_enqueue_script( 'adelle-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );

	wp_enqueue_script( 'adelle-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );

	if ( is_singular() && wp_attachment_is_image() )
		wp_enqueue_script( 'adelle-keyboard-image-navigation', get_template_directory_uri() . '/js/keyboard-image-navigation.js', array( 'jquery' ), '20120202' );
}
add_action( 'wp_enqueue_scripts', 'adelle_scripts' );

/**
/* If there's a background image or color, disable the confetti background pattern
*/
function adelle_header_css() {
	if ( '' != get_background_image() ) :
?>
	<style type="text/css">
		 .site-container {
		 	background: none;
		}
	</style>
<?php
	endif;
}
add_action( 'wp_head', 'adelle_header_css' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';


// updater for WordPress.com themes
if ( is_admin() )
	include dirname( __FILE__ ) . '/inc/updater.php';
