<?php
/**
 *
 * @package Adelle
 */

/**
 * Setup the WordPress core custom header feature.
 *
 * Use add_theme_support to register support for WordPress 3.4+
 * as well as provide backward compatibility for previous versions.
 * Use feature detection of wp_get_theme() which was introduced
 * in WordPress 3.4.
 *
 * @todo Rework this function to remove WordPress 3.4 support when WordPress 3.6 is released.
 *
 * @uses adelle_header_style()
 * @uses adelle_admin_header_style()
 * @uses adelle_admin_header_image()
 *
 * @package Adelle
 */
function adelle_custom_header_setup() {
	$args = array(
		'default-image'          => '',
		'default-text-color'     => '000',
		'width'                  => 1040,
		'height'                 => 250,
		'flex-height'            => true,
		'wp-head-callback'       => 'adelle_header_style',
		'admin-head-callback'    => 'adelle_admin_header_style',
		'admin-preview-callback' => 'adelle_admin_header_image',
	);

	$args = apply_filters( 'adelle_custom_header_args', $args );

	add_theme_support( 'custom-header', $args );
}
add_action( 'after_setup_theme', 'adelle_custom_header_setup' );

if ( ! function_exists( 'adelle_header_style' ) ) :
/**
 * Styles the header image and text displayed on the blog
 *
 * @see adelle_custom_header_setup().
 */
function adelle_header_style() {

	// If no custom options for text are set, let's bail
	// get_header_textcolor() options: HEADER_TEXTCOLOR is default, hide text (returns 'blank') or any hex value
	if ( HEADER_TEXTCOLOR == get_header_textcolor() && '' == get_header_image() )
		return;
	// If we get this far, we have custom styles. Let's do this.
	?>
	<style type="text/css">
	<?php
		// Has the text been hidden?
		if ( 'blank' == get_header_textcolor() ) :
	?>
		.site-title,
		.site-description {
			position: absolute !important;
			clip: rect(1px 1px 1px 1px); /* IE6, IE7 */
			clip: rect(1px, 1px, 1px, 1px);
		}
	<?php
		// If the user has set a custom color for the text use that
		else :
	?>
		.site-title a,
		.site-description {
			color: #<?php echo get_header_textcolor(); ?>;
		}
	<?php endif; ?>

	<?php
		// Do we have a custom header image?
		if ( '' != get_header_image() ) :
	?>
		.site-header hgroup {
			margin-bottom: 1em;
		}
		.site-header img {
			margin-bottom: 0.4em;
		}
	<?php endif; ?>
	</style>
	<?php
}
endif; // adelle_header_style

if ( ! function_exists( 'adelle_admin_header_style' ) ) :
/**
 * Styles the header image displayed on the Appearance > Header admin panel.
 *
 * @see adelle_custom_header_setup().
 */
function adelle_admin_header_style() {
?>
	<style type="text/css">
	.appearance_page_custom-header #headimg {
		border: none;
	}
	#headimg h1 {
		font-family: 'Montserrat', 'Helvetica Neue', Helvetica, Arial, sans-serif;
		font-size: 48px;
		font-weight: 400;
		line-height: 57px;
		margin: 0;
		text-transform: uppercase;
	}
	#headimg h1 a {
		text-decoration: none;
	}
	#desc {
		font-family: 'Muli', Helvetica Neue, Helvetica, Arial, sans-serif;
		font-size: 13px;
		line-height: 21px;
		margin-top: 3px;
	}
	#headimg img {
		margin-top: 8px;
	}
	</style>
<?php
}
endif; // adelle_admin_header_style

if ( ! function_exists( 'adelle_admin_header_image' ) ) :
/**
 * Custom header image markup displayed on the Appearance > Header admin panel.
 *
 * @see adelle_custom_header_setup().
 */
function adelle_admin_header_image() { ?>
	<div id="headimg">
		<?php
		if ( 'blank' == get_header_textcolor() || '' == get_header_textcolor() )
			$style = ' style="display:none;"';
		else
			$style = ' style="color:#' . get_header_textcolor() . ';"';
		?>
		<h1><a id="name"<?php echo $style; ?> onclick="return false;" href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo( 'name' ); ?></a></h1>
		<div id="desc"<?php echo $style; ?>><?php bloginfo( 'description' ); ?></div>
		<?php $header_image = get_header_image();
		if ( ! empty( $header_image ) ) : ?>
			<img src="<?php echo esc_url( $header_image ); ?>" alt="" />
		<?php endif; ?>
	</div>
<?php }
endif; // adelle_admin_header_image